==> owncloud-5.0.17.tar.bz2: owncloud/settings/l10n/vi.php <==
<?php $TRANSLATIONS = array(
"Unable to load list from App Store" => "Không thể tải danh sách ứng dụng từ App Store",
"Authentication error" => "Lỗi xác thực",
"Unable to change display name" => "Không thể thay đổi tên hiển thị",
"Group already exists" => "Nhóm đã tồn tại",
"Unable to add group" => "Không thể thêm nhóm",
"Could not enable app. " => "không thể kích hoạt ứng dụng.",
"Email saved" => "Lưu email",
"Invalid email" => "Email không hợp lệ",
"Unable to delete group" => "Không thể xóa nhóm",
"Unable to delete user" => "Không thể xóa người dùng",
"Language changed" => "Ngôn ngữ đã được thay đổi",
"Invalid request" => "Yêu cầu không hợp lệ",
"Admins can't remove themself from the admin group" => "Quản trị viên không thể loại bỏ chính họ khỏi nhóm quản lý",
"Unable to add user to group %s" => "Không thể thêm người dùng vào nhóm %s",
"Unable to remove user from group %s" => "Không thể xóa người dùng từ nhóm %s",
"Couldn't update app." => "Không thể cập nhật ứng dụng",
"Update to {appversion}" => "Cập nhật lên {appversion}",
"Disable" => "Tắt",
"Enable" => "Bật",
"Please wait...." => "Xin hãy đợi...",
"Updating...." => "Đang cập nhật...",
"Error while updating app" => "Lỗi khi cập nhật ứng dụng",
"Error" => "Lỗi",
"Updated" => "Đã cập nhật",
"Saving..." => "Đang tiến hành lưu ...",
"deleted" => "đã xóa",
"undo" => "lùi lại",
"Groups" => "Nhóm",
"Group Admin" => "Nhóm quản trị",
"Delete" => "Xóa",
"__language_name__" => "__Ngôn ngữ___",
"Security Warning" => "Cảnh bảo bảo mật",
"Your data directory and your files are probably accessible from the internet. The .htaccess file that ownCloud provides is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." => "Thư mục dữ liệu và những tập tin của bạn có thể dễ dàng bị truy cập từ mạng. Tập tin .htaccess do ownCloud cung cấp không hoạt động. Chúng tôi đề nghị bạn nên cấu hình lại máy chủ web để thư mục dữ liệu không còn bị truy cập hoặc bạn nên di chuyển thư mục dữ liệu ra bên ngoài thư mục gốc của máy chủ.",
"More" => "hơn",
"Version" => "Phiên bản",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "Được phát triển bởi <a href=\"http://ownCloud.org/contact\" target=\"_blank\">cộng đồng ownCloud</a>, <a href=\"https://github.com/owncloud\" target=\"_blank\">mã nguồn </a> đã được cấp phép theo chuẩn <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>.",
"Add your App" => "Thêm ứng dụng của bạn",
"More Apps" => "Nhiều ứng dụng hơn",
"Select an App" => "Chọn một ứng dụng",
"See application page at apps.owncloud.com" => "Xem nhiều ứng dụng hơn tại apps.owncloud.com",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-Giấy phép được cấp bởi  <span class=\"author\"></span>",
"Update" => "Cập nhật",
"User Documentation" => "Tài liệu người sử dụng",
"Administrator Documentation" => "Tài liệu quản trị",
"Online Documentation" => "Tài liệu trực tuyến",
"Forum" => "Diễn đàn",
"Bugtracker" => "Hệ ghi nhận lỗi",
"Commercial Support" => "Hỗ trợ có phí",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "Bạn đã sử dụng <strong>%s </ strong> có sẵn <strong> %s </ strong>",
"Get the apps to sync your files" => "Nhận ứng dụng để đồng bộ file của bạn",
"Show First Run Wizard again" => "Hiện lại việc chạy đồ thuật khởi đầu",
"Password" => "Mật khẩu",
"Your password was changed" => "Mật khẩu của bạn đã được thay đổi.",
"Unable to change your password" => "Không thể đổi mật khẩu",
"Current password" => "Mật khẩu cũ",
"New password" => "Mật khẩu mới ",
"Change password" => "Đổi mật khẩu",
"Display Name" => "Tên hiển thị",
"Your display name was changed" => "Tên hiển thị của bạn đã được thay đổi",
"Unable to change your display name" => "Không thể thay đổi tên hiển thị của bạn",
"Change display name" => "Thay đổi tên hiển thị",
"Email" => "Email",
"Your email address" => "Email của bạn",
"Fill in an email address to enable password recovery" => "Nhập địa chỉ email của bạn để khôi phục lại mật khẩu",
"Language" => "Ngôn ngữ",
"Help translate" => "Hỗ trợ dịch thuật",
"WebDAV" => "WebDAV",
"Use this address to connect to your ownCloud in your file manager" => "Sử dụng địa chỉ này để kết nối ownCloud của bạn trong trình quản lý file của bạn",
"Login Name" => "Tên đăng nhập",
"Create" => "Tạo",
"Default Storage" => "Bộ nhớ mặc định",
"Unlimited" => "Không giới hạn",
"Other" => "Khác",
"Storage" => "Bộ nhớ",
"change display name" => "Thay đổi tên hiển thị",
"set new password" => "đặt mật khẩu mới",
"Default" => "Mặc định"
);

==> owncloud_7.0.11~dfsg.orig.tar.bz2: owncloud/settings/l10n/vi.php <==
<?php
$TRANSLATIONS = array(
"Email sent" => "Email đã được gửi",
"Encryption" => "Mã hóa",
"Unable to load list from App Store" => "Không thể tải danh sách ứng dụng từ App Store",
"Authentication error" => "Lỗi xác thực",
"Your full name has been changed." => "Họ và tên đã được thay đổi.",
"Unable to change full name" => "Họ và tên không thể đổi ",
"Group already exists" => "Nhóm đã tồn tại",
"Unable to add group" => "Không thể thêm nhóm",
"Email saved" => "Lưu email",
"Invalid email" => "Email không hợp lệ",
"Unable to delete group" => "Không thể xóa nhóm",
"Unable to delete user" => "Không thể xóa người dùng",
"Language changed" => "Ngôn ngữ đã được thay đổi",
"Invalid request" => "Yêu cầu không hợp lệ",
"Admins can't remove themself from the admin group" => "Quản trị viên không thể loại bỏ chính họ khỏi nhóm quản lý",
"Unable to add user to group %s" => "Không thể thêm người dùng vào nhóm %s",
"Unable to remove user from group %s" => "Không thể xóa người dùng từ nhóm %s",
"Couldn't update app." => "Không thể cập nhật ứng dụng",
"User Documentation" => "Tài liệu người sử dụng",
"Update to {appversion}" => "Cập nhật lên {appversion}",
"Disable" => "Tắt",
"Enable" => "Bật",
"Please wait...." => "Xin hãy đợi...",
"Updating...." => "Đang cập nhật...",
"Error while updating app" => "Lỗi khi cập nhật ứng dụng",
"Error" => "Lỗi",
"Update" => "Cập nhật",
"Updated" => "Đã cập nhật",
"undo" => "lùi lại",
"Groups" => "Nhóm",
"Group Admin" => "Nhóm quản trị",
"Delete" => "Xóa",
"never" => "không thay đổi",
"__language_name__" => "__Ngôn ngữ___",
"None" => "Không gì cả",
"Login" => "Đăng nhập",
"Security Warning" => "Cảnh bảo bảo mật",
"Your data directory and your files are probably accessible from the internet. The .htaccess file is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." => "Thư mục và các tập tin của bạn có thể được truy cập từ Internet. Tập tin .htaccess không làm việc. Chúng tôi đề nghị bạn cấu hình ebserver ,phân quyền lại thư mục dữ liệu và cấp quyền truy cập hoặc di chuyển thư mục dữ liệu bên ngoài tài liệu gốc máy chủ web.",
"Cron" => "Cron",
"Execute one task with each page loaded" => "Thực thi tác vụ mỗi khi trang được tải",
"Sharing" => "Chia sẻ",
"Allow apps to use the Share API" => "Cho phép các ứng dụng sử dụng chia sẻ API",
"Allow resharing" => "Cho phép chia sẻ lại",
"Server address" => "Địa chỉ máy chủ",
"Port" => "Cổng",
"Credentials" => "Giấy chứng nhận",
"Log" => "Log",
"More" => "hơn",
"Less" => "ít",
"Version" => "Phiên bản",
"Developed by the <a href=\"http://ownCloud.org/contact\" target=\"_blank\">ownCloud community</a>, the <a href=\"https://github.com/owncloud\" target=\"_blank\">source code</a> is licensed under the <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>." => "Được phát triển bởi <a href=\"http://ownCloud.org/contact\" target=\"_blank\">cộng đồng ownCloud</a>, <a href=\"https://github.com/owncloud\" target=\"_blank\">mã nguồn </a> đã được cấp phép theo chuẩn <a href=\"http://www.gnu.org/licenses/agpl-3.0.html\" target=\"_blank\"><abbr title=\"Affero General Public License\">AGPL</abbr></a>.",
"Add your App" => "Thêm ứng dụng của bạn",
"More Apps" => "Nhiều ứng dụng hơn",
"Select an App" => "Chọn một ứng dụng",
"See application page at apps.owncloud.com" => "Xem nhiều ứng dụng hơn tại apps.owncloud.com",
"<span class=\"licence\"></span>-licensed by <span class=\"author\"></span>" => "<span class=\"licence\"></span>-Giấy phép được cấp bởi  <span class=\"author\"></span>",
"All" => "Tất cả",
"Administrator Documentation" => "Tài liệu quản trị",
"Online Documentation" => "Tài liệu trực tuyến",
"Forum" => "Diễn đàn",
"Bugtracker" => "Hệ ghi nhận lỗi",
"Commercial Support" => "Hỗ trợ có phí",
"Get the apps to sync your files" => "Nhận ứng dụng để đồng bộ file của bạn",
"Show First Run Wizard again" => "Hiện lại việc chạy đồ thuật khởi đầu",
"You have used <strong>%s</strong> of the available <strong>%s</strong>" => "Bạn đã sử dụng <strong>%s </ strong> có sẵn <strong> %s </ strong>",
"Password" => "Mật khẩu",
"Your password was changed" => "Mật khẩu của bạn đã được thay đổi.",
"Unable to change your password" => "Không thể đổi mật khẩu",
"Current password" => "Mật khẩu cũ",
"New password" => "Mật khẩu mới",
"Change password" => "Đổi mật khẩu",
"Full Name" => "Họ và tên",
"Email" => "Email",
"Your email address" => "Email của bạn",
"Upload new" => "Tải lên",
"Remove image" => "Xóa ",
"Cancel" => "Hủy",
"Choose as profile image" => "Chọn hình ảnh như hồ sơ cá nhân",
"Language" => "Ngôn ngữ",
"Help translate" => "Hỗ trợ dịch thuật",
"Login Name" => "Tên đăng nhập",
"Create" => "Tạo",
"Group" => "N",
"Default Quota" => "Hạn ngạch mặt định",
"Unlimited" => "Không giới hạn",
"Other" => "Khác",
"Username" => "Tên đăng nhập",
"Quota" => "Hạn ngạch",
"change full name" => "Đổi họ và t",
"set new password" => "đặt mật khẩu mới",
"Default" => "Mặc định"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
